@@ -14,7 +14,7 @@ async def main() -> None:
                 "content": "Say hello there!",
             }
         ],
-        model="claude-3-opus-20240229",
+        model="claude-3-5-sonnet-latest",
     ) as stream:
         async for event in stream:
             if event.type == "text":
